@@ -12,7 +12,7 @@ even though multiple purposes may actually be present in a single packet.
 """
 
 import struct
-from collections import OrderedDict
+from collections import OrderedDict, namedtuple
 
 from . import (
     Advertisement,
@@ -261,6 +261,9 @@ class ManufacturerDataField:
             )
         self._entry_length = struct.calcsize(value_format)
         self.field_names = field_names
+        if field_names:
+            # Mostly, this is to raise a ValueError if field_names has invalid entries
+            self.mdf_tuple = namedtuple("mdf_tuple", self.field_names)
 
     def __get__(self, obj, cls):
         if obj is None:
@@ -272,6 +275,10 @@ class ManufacturerDataField:
             unpacked = struct.unpack_from(self._format, packed)
             if self.element_count == 1:
                 unpacked = unpacked[0]
+            if self.field_names and len(self.field_names) == len(unpacked):
+                # If we have field names, we should already have a namedtuple type to use
+                # Unless the element count is off, which... werid.
+                return self.mdf_tuple(*unpacked)
             return unpacked
         if len(packed) % self._entry_length != 0:
             raise RuntimeError("Invalid data length")
